@@ -1,7 +1,15 @@
+#![cfg_attr(feature = "dox", feature(doc_cfg))]
+
 mod auto;
+pub use auto::*;
+
+mod document;
+mod movie;
+mod page_range;
+pub use page_range::PageRange;
+
 use std::ops::{Deref, DerefMut};
 
-pub use auto::*;
 use glib::translate::{ToGlibPtr, ToGlibPtrMut};
 
 impl Deref for Rectangle {
